# FINAM

FINAM is an open-source component-based model coupling framework for environmental models.
It aims at enabling bi-directional online couplings of models for different compartments like geo-, hydro-, pedo- and biosphere.

<a href="https://finam.pages.ufz.de" title="FINAM homepage" target="_blank">
  <img width="300" src="https://git.ufz.de/FINAM/finam/-/raw/main/docs/source/_static/logo_large.svg" />
</a>

The framework is built in Python, with well-defined interfaces for data exchange.
This approach allows for coupling of models irrespective of their internal structure, architecture or programming language.

## Resources

* FINAM [homepage](https://finam.pages.ufz.de)
* FINAM [documentation](https://finam.pages.ufz.de/finam/)
* FINAM [source code](https://git.ufz.de/FINAM/finam)
* FINAM [GitLab group](https://git.ufz.de/FINAM), containing further related projects

## License

LGPLv3, Copyright © 2021-2025, the FINAM developers from Helmholtz-Zentrum für Umweltforschung GmbH - UFZ. All rights reserved.
